@@ -6,11 +6,10 @@ use warnings;
 use DBI;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
-use Test::BDD::Cucumber::Definitions qw(S);
-use Test::BDD::Cucumber::Definitions::Validator qw(:all);
+use Test::BDD::Cucumber::Definitions qw(S :validator);
 use Test::More;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 our @EXPORT_OK = qw(Base);
 
