@@ -6,7 +6,7 @@ use warnings;
 use DDP ( show_unicode => 1 );
 use MooseX::Types::Common::String qw(NonEmptyStr);
 use MooseX::Types::Moose qw(Int Str RegexpRef);
-use Test::BDD::Cucumber::Definitions qw(S);
+use Test::BDD::Cucumber::StepFile qw();
 use Test::More;
 use Try::Tiny;
 
@@ -21,7 +21,9 @@ use MooseX::Types (
     ]
 );
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
+
+sub S { return Test::BDD::Cucumber::StepFile::S }
 
 # Interpolation of variables (scenario and environment)
 sub _interpolate {
