@@ -7,12 +7,11 @@ use Archive::Zip;
 use DDP ( show_unicode => 1 );
 use Exporter qw(import);
 use IO::String;
-use Test::BDD::Cucumber::Definitions qw(S);
-use Test::BDD::Cucumber::Definitions::Validator qw(:all);
+use Test::BDD::Cucumber::Definitions qw(S :validator);
 use Test::More;
 use Try::Tiny;
 
-our $VERSION = '0.38';
+our $VERSION = '0.39';
 
 our @EXPORT_OK = qw(Zip);
 
